@@ -1,15 +1,13 @@
 import os
 import shutil
 from pathlib import Path
-from typing import Optional, List
+from typing import List, Optional
 
 # From Third party
 import click
 from colorama import Fore
-
 # From This Project
-from fdn.fdnlib import fdnutils
-from fdn.fdnlib import utils
+from fdn.fdnlib import fdnutils, utils
 from fdn.fdnlib.fdncfg import gParamDict as ugPD
 
 
@@ -162,3 +160,4 @@ def ufn(path: Optional[List[Path]], max_depth: int, file_type: str,
 # TODO: bug:fd -x can not get terminal size .so fall back and no color display
 # TODO: autocomplete
 # TODO: different language can use separator for terminology
+# TODO: C++ --> C ...?!
